@@ -12,5 +12,5 @@ from .app import create_cli
 
 cli = create_cli()
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == "__main__":  # pragma: no cover
     cli()
