@@ -8,21 +8,15 @@
 
 """Pytest configuration."""
 
-from __future__ import absolute_import, print_function
 
-import shutil
 import tempfile
 
 import pytest
 
 
-@pytest.fixture
-def tmppath(request):
+@pytest.fixture()
+def tmppath():
     """Application fixture."""
     tmppath = tempfile.mkdtemp()
-
-    def teardown():
-        shutil.rmtree(tmppath)
-
-    request.addfinalizer(teardown)
+    yield tmppath
     return tmppath
